@@ -17,7 +17,12 @@ import aws_cdk.core._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-lambda-elasticsearch-kibana", "1.47.0", __name__[0:-6], "aws-lambda-elasticsearch-kibana@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-lambda-elasticsearch-kibana",
+    "1.49.0",
+    __name__[0:-6],
+    "aws-lambda-elasticsearch-kibana@1.49.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
